GeoAddressComponent class

Represents a single address component returned from a geocoding service.

Constructors

GeoAddressComponent({required String longName, required String shortName, List<String> types = const []})
Creates a GeoAddressComponent instance.
const
GeoAddressComponent.fromJson(Map<String, dynamic> json)
Creates a GeoAddressComponent from a JSON map.
factory
GeoAddressComponent.fromJsonString(String source)
Creates a GeoAddressComponent from a JSON string.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
longName String
The full name of the address component.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortName String
The abbreviated or short name of the address component.
final
types List<String>
The types associated with this address component.
final

Methods

copyWith({String? longName, String? shortName, List<String>? types}) GeoAddressComponent
Creates a copy with optional updated fields.
hasType(String type) bool
Checks if this component contains the specified type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this instance to a JSON map.
toJsonString() String
Converts this instance to a JSON string.
toMap() Map<String, dynamic>
Converts this instance to a map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override