QuotaExceededException class

Thrown when the query limit or API quota has been exceeded.

Inheritance

Constructors

QuotaExceededException(String message, {dynamic statusCode = 'OVER_QUERY_LIMIT', dynamic details})
Creates a QuotaExceededException.
const

Properties

details → dynamic
Additional diagnostic details or original provider response.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
The human-readable error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode → dynamic
The HTTP or API status code, if available.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited